# BeForData

Data structure for handling behavioural force data

[![GitHub license](https://img.shields.io/github/license/lindemann09/befordata)](https://github.com/lindemann09/befordata/blob/master/LICENSE)
[![Python Version](https://img.shields.io/pypi/pyversions/befordata?style=flat)](https://www.python.org)
[![PyPI](https://img.shields.io/pypi/v/befordata?style=flat)](https://pypi.org/project/befordata/)


## Install via pip

```
pip install befordata
```


[BeForData Demo](https://lindemann09.github.io/befordata/demo_befordata.html)


(c) Oliver Lindemann
